@@ -2,7 +2,7 @@
 #'
 #' @param resolution The resolution of the cartographic boundary file.
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -23,7 +23,7 @@ regions <- function(resolution = '500k', year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -44,7 +44,7 @@ regions <- function(resolution = '500k', year = NULL, ...) {
 
   cyear <- as.character(year)
 
-  url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_region_%s.zip",
+  url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_region_%s.zip",
                  cyear, cyear, resolution)
 
   rgns <- load_tiger(url, tigris_type = "region")
@@ -57,7 +57,7 @@ regions <- function(resolution = '500k', year = NULL, ...) {
 #'
 #' @param resolution The resolution of the cartographic boundary file.
 #'        Defaults to '500k'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -78,7 +78,7 @@ divisions <- function(resolution = '500k', year = NULL, ...) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -99,7 +99,7 @@ divisions <- function(resolution = '500k', year = NULL, ...) {
 
   cyear <- as.character(year)
 
-  url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_division_%s.zip",
+  url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_division_%s.zip",
                  cyear, cyear, resolution)
 
   div <- load_tiger(url, tigris_type = "division")
@@ -112,7 +112,7 @@ divisions <- function(resolution = '500k', year = NULL, ...) {
 #'
 #' @param resolution The resolution of the cartographic boundary file.
 #'        Defaults to '5m'; options include '5m' (1:5 million) and '20m' (1:20 million).
-#' @param year the data year (defaults to 2015).
+#' @param year the data year (defaults to 2016).
 #' @param ... arguments to be passed to the underlying `load_tiger` function, which is not exported.
 #'        Options include \code{refresh}, which specifies whether or not to re-download shapefiles
 #'        (defaults to \code{FALSE}).
@@ -133,7 +133,7 @@ nation <- function(resolution = '5m', year = NULL) {
 
   if (is.null(year)) {
 
-    year <- getOption("tigris_year", 2015)
+    year <- getOption("tigris_year", 2016)
 
   }
 
@@ -154,7 +154,7 @@ nation <- function(resolution = '5m', year = NULL) {
 
   cyear <- as.character(year)
 
-  url <- sprintf("http://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_nation_%s.zip",
+  url <- sprintf("https://www2.census.gov/geo/tiger/GENZ%s/shp/cb_%s_us_nation_%s.zip",
                  cyear, cyear, resolution)
 
   nat <- load_tiger(url, tigris_type = "nation")
